signIn static method

AuthProvider for performing Authentication.signIn.

Authentication.signInを実行するためのAuthProvider

An AuthQuery to authenticate with a Google account on Firebase.

signIn and reauth are available.

signOut logs you out of your Google account rather than providing Provider.

FirebaseにおけるGoogleアカウントでの認証を行うためのAuthQuery

signInおよびreauthが利用可能です。

signOutはProviderを提供するのではなくGoogleアカウントからログアウトします。

Implementation

static FirebaseGoogleSignInAuthProvider signIn() {
  return const FirebaseGoogleSignInAuthProvider();
}