FirebaseGoogleAuthQuery class
An AuthQuery to authenticate with a Google account on Firebase.
signIn and reauth are available.
signOut logs you out of your Google account rather than providing Provider.
FirebaseにおけるGoogleアカウントでの認証を行うためのAuthQuery。
signOutはProviderを提供するのではなくGoogleアカウントからログアウトします。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
reauth(
) → FirebaseGoogleReAuthProvider -
AuthProviderfor performingAuthentication.reauth. -
signIn(
) → FirebaseGoogleSignInAuthProvider -
AuthProviderfor performingAuthentication.signIn.
Constants
- providerId → const String
- ID that defines the provider's process.