FirebaseGoogleReAuthProvider class
An AuthQuery for Google's OAuth authentication on Firebase.
FirebaseにおけるGoogleのOAuth認証を行うためのAuthQuery。
- Inheritance
-
- Object
- AuthProvider
- ReAuthProvider
- FirebaseSnsReAuthProvider
- FirebaseGoogleReAuthProvider
Constructors
- FirebaseGoogleReAuthProvider()
-
An
AuthQueryfor Google's OAuth authentication on Firebase.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerId → String
-
ID that defines the provider's process.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authProvider(
) → AuthProvider -
Obtain an authentication provider for SNS re-authentication in Firebase.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited